@@ -16,10 +16,40 @@ require AutoLoader;
 
 @ISA = qw(DynaLoader);
 
-$VERSION = '0.09';
+$VERSION = '0.10';
 
 bootstrap Text::Tmpl $VERSION;
 
+###############################################################################
+## set_values
+##   Purpose:
+##     Load a hash table into a template
+##   Usage:
+##     $context->set_values({ 'var1' => 'value1',
+##                            'var2' => 'value2' });
+##   Return Values:
+##     Returns 1 on success, 0 on failure.
+###############################################################################
+sub set_values {
+    my $self = shift;
+    if (! ref $self) {
+        return 0;
+    }
+    my($hashref) = shift;
+    if ((ref $hashref) ne 'HASH') {
+        return 0;
+    }
+
+    foreach my $key (keys %{$hashref}) {
+        my $ret = $self->set_value($key, $hashref->{$key});
+        if (! $ret) {
+            return 0;
+        }
+    }
+    return 1;
+}
+### end set_values ############################################################
+
 1;
 
 __END__
@@ -51,6 +81,8 @@ $return     = $context->B<set_dir>($directory);
 
 $return     = $context->B<set_value>($name, $value);
 
+$return     = $context->B<set_values>($hashref);
+
 $subcontext = $context->B<loop_iteration>($loop_name);
 
 $output     = B<Text::Tmpl::parse_file>($context,
@@ -96,6 +128,11 @@ limit of 6 characters on these strings.
 
 This function stores the name=value pair in the current context.
 
+=item B<Text::Tmpl::set_values>
+
+This function dumps the name=value pairs from a hash reference into the
+current context.
+
 =item B<Text::Tmpl::set_debug>
 
 This function sets the debugging level (from 0 = silent to 2 = verbose).  Note
@@ -155,8 +192,7 @@ they fail, or a valid pointer otherwise.
 
 =head1 BUGS
 
-Got the OO-style notation to work, but not for all functions (the others
-still cause nasty core dumps).
+Hopefully none.
 
 =head1 AUTHOR
 
